"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeTestDialog = exports.watch = exports.study = void 0;
const util_1 = require("../util");
/**
 * zhs 视频学习
 * @param options {@link StudyOptions}
 * @returns
 */
function study(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { watchTime = 30, restudy = false } = options || {};
        (0, util_1.logger)("info", "zhs 学习任务开始");
        yield new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            /** 查找任务 */
            let list = Array.from(document.querySelectorAll("li.clearfix.video"));
            /** 如果不是复习模式，则排除掉已经完成的任务 */
            if (!restudy) {
                list = list.filter((el) => el.querySelector(".time_icofinish") === null);
            }
            if (list.length === 0) {
                (0, util_1.logger)("warn", "视频任务数量为 0 !");
            }
            else {
                (0, util_1.logger)("info", "视频任务数量", list.length);
                let stop = false;
                /**
                 * 实时监测，关闭弹窗测验
                 */
                setInterval(() => {
                    closeTestDialog();
                }, 3000);
                /**
                 * 到达学习时间后，自动关闭
                 */
                if (watchTime !== 0) {
                    (0, util_1.logger)("info", "将在", watchTime, "分钟后自动暂停");
                    setTimeout(() => {
                        const video = document.querySelector("video");
                        video.stop = true;
                        video.pause();
                        stop = true;
                        resolve();
                    }, watchTime * 60 * 1000);
                }
                /** 遍历任务进行学习 */
                for (const item of list) {
                    try {
                        if (stop) {
                            break;
                        }
                        else {
                            (0, util_1.logger)("debug", `${(_a = item.querySelector('[class="catalogue_title"]')) === null || _a === void 0 ? void 0 : _a.getAttribute("title")} : ${(_b = item.querySelector(".time")) === null || _b === void 0 ? void 0 : _b.textContent}`);
                            item.click();
                            yield (0, util_1.sleep)(5000);
                            yield watch(options);
                        }
                    }
                    catch (e) {
                        (0, util_1.logger)("error", e);
                    }
                }
            }
            resolve();
        }));
        (0, util_1.logger)("info", "zhs 学习任务结束");
    });
}
exports.study = study;
/**
 * 观看视频
 * @param options {@link VideoOptions}
 * @returns
 */
function watch(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { playbackRate = 1, mute = true } = options || {};
        return new Promise((resolve, reject) => {
            try {
                const video = document.querySelector("video");
                video.playbackRate = playbackRate;
                video.muted = mute;
                video.onpause = function () {
                    if (!video.ended) {
                        if (video.stop) {
                            resolve();
                        }
                        else {
                            video.play();
                        }
                    }
                };
                video.onended = function () {
                    resolve();
                };
                video.play();
            }
            catch (e) {
                reject(e);
            }
        });
    });
}
exports.watch = watch;
/**
 * 关闭zhs测验弹窗
 */
function closeTestDialog() {
    return __awaiter(this, void 0, void 0, function* () {
        if (document.querySelectorAll(".topic-item").length != 0) {
            //选择A
            document.querySelector(".topic-item").click();
            yield (0, util_1.sleep)(500);
            //关闭
            document.querySelector(`[aria-label="弹题测验"] .btn`).click();
            yield (0, util_1.sleep)(500);
        }
    });
}
exports.closeTestDialog = closeTestDialog;
