"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ocr = void 0;
const axios_1 = __importDefault(require("axios"));
const API_URL = "http://api.ttshitu.com/predict";
/**
 * ocr 文字识别
 * - `buffer` 流数据
 * - `account` 账号
 * - `password` 密码
 * - `typeid` 类型
 * ```
 * 1 : 纯数字
 * 1001：纯数字2
 * 2 : 纯英文
 * 1002：纯英文2
 * 3 : 数英混合
 * ```
 * @see https://ttshitu.com/
 */
function ocr(buffer, { username, password, typeid = "1" }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let base64data = buffer.toString("base64");
            const response = yield axios_1.default.post(API_URL, {
                username,
                password,
                typeid,
                image: base64data,
            });
            let d = response.data;
            if (d.success) {
                // handle success
                let { id, result } = d.data;
                return result;
            }
            else {
                return undefined;
            }
        }
        catch (__) {
            return undefined;
        }
    });
}
exports.ocr = ocr;
